@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.2');    # update POD & Changes & README
+use version; our $VERSION = qv('0.1.3');    # update POD & Changes & README
 
 # update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
@@ -12,9 +12,9 @@ use IO::Stream;
 use Inferno::RegMgr::Utils qw( run_callback quote attr parse_svc );
 
 
-use constant PORT_NEW   => 16675;
-use constant PORT_FIND  => 26675;
-use constant PORT_EVENT => 36675;
+use constant PORT_NEW   => 6701;
+use constant PORT_FIND  => 6702;
+use constant PORT_EVENT => 6703;
 use constant KiB        => 1024;    ## no critic (Capitalization)
 
 
@@ -244,22 +244,24 @@ objects - to be able to interrupt their task (using $io->close()).
 Example commands to provide access to registry using TCP ports, in a way
 compatible with this module:
 
- #!/dis/sh
- # (for perl) plain tcp interface to /mnt/registry/{new,find,event}
- listen -A -s tcp!127.0.0.1!16675 { cat >/mnt/registry/new & } &
- listen -A -s tcp!127.0.0.1!26675 { {
-     read >[1=3]; read -o 0 0 <[0=3]; cat >[1=0] <[0=3]
-     } <>[3]/mnt/registry/find & } &
- # 'echo READY' needed to workaround race: between connecting to tcp port
- # and opening event file may happens some events which will be lost in
- # case client expect to get ALL events after establishing connection
- listen -A -s tcp!127.0.0.1!36675 { {
-     echo READY
-     cat &                      pid1 := $apid
-     cat <[0=1] >/dev/null &    pid2 := $apid
-     { read < /prog/$pid2/wait; kill $pid1 >[2]/dev/null } &
-     read < /prog/$pid1/wait; kill $pid2 >[2]/dev/null
-     } </mnt/registry/event & } &
+    #!/dis/sh
+    # (for perl) plain tcp interface to /mnt/registry/{new,find,event}
+    listen -A tcp!127.0.0.1!6701 { {
+        cat >/mnt/registry/new
+        } & }
+    listen -A tcp!127.0.0.1!6702 { {
+        read >[1=3]; read -o 0 0 <[0=3]; cat >[1=0] <[0=3]
+        } <>[3]/mnt/registry/find & }
+    # 'echo READY' needed to workaround race: between connecting to tcp port
+    # and opening event file may happens some events which will be lost in
+    # case client expect to get ALL events after establishing connection
+    listen -A tcp!127.0.0.1!6703 { {
+        echo READY
+        cat &                      pid1 := $apid
+        cat <[0=1] >/dev/null &    pid2 := $apid
+        { read < /prog/$pid2/wait; kill $pid1 >[2]/dev/null } &
+        read < /prog/$pid1/wait; kill $pid2 >[2]/dev/null
+        } </mnt/registry/event & }
 
 
 =head1 INTERFACE 
@@ -273,9 +275,9 @@ Create and return Inferno::RegMgr::TCP object.
 Accept HASHREF with options:
 
  host       REQUIRED
- port_new   OPTIONAL, DEFAULT 16675
- port_find  OPTIONAL, DEFAULT 26675
- port_event OPTIONAL, DEFAULT 36675
+ port_new   OPTIONAL, DEFAULT 6701
+ port_find  OPTIONAL, DEFAULT 6702
+ port_event OPTIONAL, DEFAULT 6703
 
 This hostname and ports will be used by methods open_new(), open_find()
 and open_event().
